==> Renard-Curie-0.001_01.tar.gz: Renard-Curie-0.001_01/README.md <==
# Curie

<table>
	<thead>
		<tr>
			<th>CI build</th>
			<th>Coverage</th>
			<th>CPAN</th>
		</tr>
	</thead>
	<tr>
		<td>
			<table>
				<thead>
					<tr>
						<th align="center">OS</th>
						<th align="right">Status</th>
					</tr>
				</thead>
				<tr>
					<td align="center">Linux &amp; OS X</td>
					<td align="right">
						<!-- [![Build Status](https://travis-ci.org/project-renard/curie.svg?branch=master)](https://travis-ci.org/project-renard/curie) -->
						<a href="https://travis-ci.org/project-renard/curie"><img src="https://travis-ci.org/project-renard/curie.svg?branch=master" alt="Build status" /></a>
					</td>
				</tr>
				<tr>
					<td align="center"> Windows </td>
					<td align="right">
						<!-- [![Build status](https://ci.appveyor.com/api/projects/status/d1oln5wwo7rkyxp0/branch/master?svg=true)](https://ci.appveyor.com/project/zmughal/curie/branch/master) -->
						<a href="https://ci.appveyor.com/project/zmughal/curie/branch/master"><img src="https://ci.appveyor.com/api/projects/status/d1oln5wwo7rkyxp0/branch/master?svg=true" alt="Build status" /></a>
					</td>
				</tr>
			</table>
		</td>
		<td>
			<!-- [![Coverage Status](https://coveralls.io/repos/project-renard/curie/badge.svg?branch=master)](https://coveralls.io/r/project-renard/curie?branch=master) -->
			<a href="https://coveralls.io/r/project-renard/curie?branch=master"><img src="https://coveralls.io/repos/project-renard/curie/badge.svg?branch=master" alt="Coverage Status" /></a>
		</td>
		<td>
			<!-- [![CPAN version](https://badge.fury.io/pl/Renard-Curie.svg)](https://metacpan.org/pod/Renard::Curie) -->
            <a href="https://metacpan.org/pod/Renard::Curie"><img src="https://badge.fury.io/pl/Renard-Curie.svg" alt="CPAN version" /></a>
		</td>
	</tr>
</table>

==> Renard-Curie-0.004.tar.gz: Renard-Curie-0.004/README.md <==
# Curie

<table>
	<thead>
		<tr>
			<th>CI build</th>
			<th>Coverage</th>
			<th>CPAN</th>
		</tr>
	</thead>
	<tr>
		<td>
			<table>
				<thead>
					<tr>
						<th align="center">OS</th>
						<th align="right">Status</th>
					</tr>
				</thead>
				<tr>
					<td align="center">Linux &amp; OS X</td>
					<td align="right">
						<!-- [![Build Status](https://travis-ci.org/project-renard/curie.svg?branch=master)](https://travis-ci.org/project-renard/curie) -->
						<a href="https://travis-ci.org/project-renard/curie"><img src="https://travis-ci.org/project-renard/curie.svg?branch=master" alt="Build status" /></a>
					</td>
				</tr>
				<tr>
					<td align="center"> Windows </td>
					<td align="right">
						<!-- [![Build status](https://ci.appveyor.com/api/projects/status/d1oln5wwo7rkyxp0/branch/master?svg=true)](https://ci.appveyor.com/project/zmughal/curie/branch/master) -->
						<a href="https://ci.appveyor.com/project/zmughal/curie/branch/master"><img src="https://ci.appveyor.com/api/projects/status/d1oln5wwo7rkyxp0/branch/master?svg=true" alt="Build status" /></a>
					</td>
				</tr>
			</table>
		</td>
		<td>
			<!-- [![Coverage Status](https://coveralls.io/repos/project-renard/curie/badge.svg?branch=master)](https://coveralls.io/r/project-renard/curie?branch=master) -->
			<a href="https://coveralls.io/r/project-renard/curie?branch=master"><img src="https://coveralls.io/repos/project-renard/curie/badge.svg?branch=master" alt="Coverage Status" /></a>
		</td>
		<td>
			<!-- [![CPAN version](https://badge.fury.io/pl/Renard-Curie.svg)](https://metacpan.org/pod/Renard::Curie) -->
            <a href="https://metacpan.org/pod/Renard::Curie"><img src="https://badge.fury.io/pl/Renard-Curie.svg" alt="CPAN version" /></a>
		</td>
	</tr>
</table>

# Screenshot

Curie v0.001 displaying an excerpt from "Ways of coloring: Comparative color vision as a case study for cognitive science"

<img caption="" src="https://project-renard.github.io/blog/posts/2016/09/22/gfx/curie-v0.001-ways-of-colouring.png"/>
